@@ -11,7 +11,7 @@ from flufl.i18n.types import (
 )
 
 
-__version__ = '4.1'
+__version__ = '5.0.1'
 
 
 _public(
@@ -28,7 +28,7 @@ _public(
 
 @_public
 def initialize(domain: str) -> RuntimeTranslator:
-    """A convenience function for setting up translation.
+    """Initialize a translation context.
 
     :param domain: The application's name.
     :return: The translation function, typically bound to _()
